@@ -19,7 +19,7 @@ import glob
 import sys
 
 from calculate.lib.cl_lang import setLocalTranslate
-from calculate.lib.utils.files import readLinesFile, pathJoin
+from calculate.lib.utils.files import readLinesFile, pathJoin, readFile
 
 _ = lambda x: x
 setLocalTranslate('cl_core3', sys.modules[__name__])
@@ -297,7 +297,7 @@ class VariableClReqGroup(Variable):
     def choice(self):
         group_rights = self.Get('cl_core_group_rights_path')
 
-        t = open(group_rights, 'r').read()
+        t = readFile(group_rights)
         result = []
         for line in t.splitlines():
             words = line.split()
@@ -334,7 +334,7 @@ class VariableClReqGroup(Variable):
 
         if group == 'all':
             return
-        t = open(group_rights, 'r').read()
+        t = readFile(group_rights)
         for line in t.splitlines():
             words = line.split()
             if words[0].startswith('#'):
